@@ -21,7 +21,7 @@
 #include "musicaudiotrack.h"
 #include "databaseinterface.h"
 #include "models/albummodel.h"
-#include "modeltest.h"
+#include "qabstractitemmodeltester.h"
 
 #include <QObject>
 #include <QUrl>
@@ -204,7 +204,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
-        ModelTest testModel(&albumsModel);
+        QAbstractItemModelTester testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -256,7 +256,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
-        ModelTest testModel(&albumsModel);
+        QAbstractItemModelTester testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -316,7 +316,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
-        ModelTest testModel(&albumsModel);
+        QAbstractItemModelTester testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
@@ -416,7 +416,7 @@ private Q_SLOTS:
     {
         DatabaseInterface musicDb;
         AlbumModel albumsModel;
-        ModelTest testModel(&albumsModel);
+        QAbstractItemModelTester testModel(&albumsModel);
 
         connect(&musicDb, &DatabaseInterface::albumModified,
                 &albumsModel, &AlbumModel::albumModified);
