@@ -36,6 +36,7 @@
 class AbstractFileListingPrivate;
 class MusicAudioTrack;
 class NotificationItem;
+class FileScanner;
 
 class ELISALIB_EXPORT AbstractFileListing : public QObject
 {
@@ -120,6 +121,8 @@ protected:
 
     void checkFilesToRemove();
 
+    FileScanner& fileScanner();
+
 private:
 
     std::unique_ptr<AbstractFileListingPrivate> d;
