@@ -27,6 +27,10 @@
 #include "baloo/scheduler.h"
 #include "baloo/fileindexer.h"
 
+#include "baloowatcherapplicationadaptor.h"
+
+#include "filescanner.h"
+
 #include <Baloo/Query>
 #include <Baloo/File>
 #include <Baloo/IndexerConfig>
@@ -69,6 +73,8 @@ public:
 
     QAtomicInt mStopRequest = 0;
 
+    BalooWatcherApplicationAdaptor *mDbusAdaptor = nullptr;
+
     bool mIsRegistered = false;
 
     bool mIsRegistering = false;
@@ -83,6 +89,10 @@ LocalBalooFileListing::LocalBalooFileListing(QObject *parent)
 
     auto sessionBus = QDBusConnection::sessionBus();
 
+    d->mDbusAdaptor = new BalooWatcherApplicationAdaptor(this);
+
+    sessionBus.registerObject(QStringLiteral("/org/kde/BalooWatcherApplication"), d->mDbusAdaptor, QDBusConnection::ExportAllContents);
+
     connect(&d->mServiceWatcher, &QDBusServiceWatcher::serviceRegistered,
             this, &LocalBalooFileListing::serviceRegistered);
     connect(&d->mServiceWatcher, &QDBusServiceWatcher::serviceOwnerChanged,
@@ -190,6 +200,22 @@ void LocalBalooFileListing::registerToBaloo()
     if (pendingCallWatcher->isFinished()) {
         registeredToBaloo(pendingCallWatcher);
     }
+
+    QDBusMessage registerBalooWatcher = QDBusMessage::createMethodCall(QStringLiteral("org.kde.baloo"),
+                                                                       QStringLiteral("/"),
+                                                                       QStringLiteral("org.kde.baloo.main"),
+                                                                       QStringLiteral("registerBalooWatcher"));
+
+    registerBalooWatcher.setArguments({QStringLiteral("org.mpris.MediaPlayer2.elisa/org/kde/BalooWatcherApplication")});
+
+    auto pendingCall = sessionBus.asyncCall(registerBalooWatcher);
+    qDebug() << "LocalBalooFileListing::registerToBaloo" << "call registerBalooWatcher";
+    auto pendingCallWatcher2 = new QDBusPendingCallWatcher(pendingCall);
+
+    connect(pendingCallWatcher2, &QDBusPendingCallWatcher::finished, this, &LocalBalooFileListing::registeredToBaloo);
+    if (pendingCallWatcher2->isFinished()) {
+        registeredToBaloo(pendingCallWatcher2);
+    }
 }
 
 void LocalBalooFileListing::renamedFiles(const QString &from, const QString &to, const QStringList &listFiles)
@@ -301,9 +327,7 @@ MusicAudioTrack LocalBalooFileListing::scanOneFile(const QUrl &scanFile)
     newTrack.setFileModificationTime(scanFileInfo.fileTime(QFile::FileModificationTime));
     newTrack.setResourceURI(scanFile);
 
-    const auto &allProperties = match.properties();
-
-    ElisaUtils::scanProperties(localFileName, allProperties, newTrack);
+    fileScanner().scanProperties(match, newTrack);
 
     if (!newTrack.isValid()) {
         newTrack = AbstractFileListing::scanOneFile(scanFile);
