@@ -26,7 +26,11 @@
 #include "models/allartistsproxymodel.h"
 #include "models/singleartistproxymodel.h"
 #include "models/singlealbumproxymodel.h"
+
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
 #include "models/filebrowserproxymodel.h"
+#endif
+
 #include "mediaplaylist.h"
 #include "audiowrapper.h"
 #include "manageaudioplayer.h"
@@ -109,7 +113,9 @@ public:
 
     std::unique_ptr<SingleAlbumProxyModel> mSingleAlbumProxyModel;
 
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
     std::unique_ptr<FileBrowserProxyModel> mFileBrowserProxyModel;
+#endif
 
     std::unique_ptr<MediaPlayList> mMediaPlayList;
 
@@ -168,6 +174,12 @@ void ElisaApplication::setupActions(const QString &actionName)
         d->mCollection.addAction(goBackAction->objectName(), goBackAction);
     }
 
+    if (actionName == QStringLiteral("toggle_playlist") && KAuthorized::authorizeAction(actionName)) {
+        auto togglePlaylistAction = d->mCollection.addAction(actionName, this, &ElisaApplication::togglePlaylist);
+        togglePlaylistAction->setShortcut(QKeySequence(Qt::Key_F9));
+        togglePlaylistAction->setText(QStringLiteral("Toggle Playlist"));
+    }
+
     if (actionName == QStringLiteral("edit_find") && KAuthorized::authorizeAction(actionName)) {
         auto findAction = KStandardAction::find(this, &ElisaApplication::find, this);
         d->mCollection.addAction(findAction->objectName(), findAction);
@@ -265,6 +277,8 @@ void ElisaApplication::goBack() {}
 
 void ElisaApplication::find() {}
 
+void ElisaApplication::togglePlaylist() {}
+
 QStringList ElisaApplication::checkFileListAndMakeAbsolute(const QStringList &filesList, const QString &workingDirectory) const
 {
     QStringList filesToOpen;
@@ -288,6 +302,8 @@ void ElisaApplication::initialize()
 {
     initializeModels();
     initializePlayer();
+
+    Q_EMIT initializationDone();
 }
 
 void ElisaApplication::initializeModels()
@@ -310,8 +326,12 @@ void ElisaApplication::initializeModels()
     Q_EMIT singleArtistProxyModelChanged();
     d->mSingleAlbumProxyModel = std::make_unique<SingleAlbumProxyModel>();
     Q_EMIT singleAlbumProxyModelChanged();
+
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
     d->mFileBrowserProxyModel = std::make_unique<FileBrowserProxyModel>();
     Q_EMIT fileBrowserProxyModelChanged();
+#endif
+
     d->mMediaPlayList = std::make_unique<MediaPlayList>();
     Q_EMIT mediaPlayListChanged();
 
@@ -352,11 +372,12 @@ void ElisaApplication::initializeModels()
                                                                          ElisaUtils::PlayListEnqueueMode,
                                                                          ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayList::enqueue));
 
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
     QObject::connect(d->mFileBrowserProxyModel.get(), &FileBrowserProxyModel::filesToEnqueue,
                      d->mMediaPlayList.get(), static_cast<void (MediaPlayList::*)(const QList<QUrl> &,
                                                                          ElisaUtils::PlayListEnqueueMode,
                                                                          ElisaUtils::PlayListEnqueueTriggerPlay)>(&MediaPlayList::enqueue));
-
+#endif
 }
 
 void ElisaApplication::initializePlayer()
@@ -407,6 +428,7 @@ void ElisaApplication::initializePlayer()
     d->mManageHeaderBar->setAlbumRole(MediaPlayList::AlbumRole);
     d->mManageHeaderBar->setArtistRole(MediaPlayList::ArtistRole);
     d->mManageHeaderBar->setImageRole(MediaPlayList::ImageRole);
+    d->mManageHeaderBar->setAlbumIdRole(MediaPlayList::AlbumIdRole);
     d->mManageHeaderBar->setIsValidRole(MediaPlayList::IsValidRole);
     d->mManageHeaderBar->setPlayListModel(d->mMediaPlayList.get());
     QObject::connect(d->mMediaPlayList.get(), &MediaPlayList::currentTrackChanged, d->mManageHeaderBar.get(), &ManageHeaderBar::setCurrentTrack);
@@ -449,49 +471,53 @@ MusicListenersManager *ElisaApplication::musicManager() const
     return d->mMusicManager.get();
 }
 
-AllAlbumsProxyModel *ElisaApplication::allAlbumsProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allAlbumsProxyModel() const
 {
     return d->mAllAlbumsProxyModel.get();
 }
 
-AllArtistsProxyModel *ElisaApplication::allArtistsProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allArtistsProxyModel() const
 {
     return d->mAllArtistsProxyModel.get();
 }
 
-AllArtistsProxyModel *ElisaApplication::allGenresProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allGenresProxyModel() const
 {
     return d->mAllGenresProxyModel.get();
 }
 
-AllArtistsProxyModel *ElisaApplication::allComposersProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allComposersProxyModel() const
 {
     return d->mAllComposersProxyModel.get();
 }
 
-AllArtistsProxyModel *ElisaApplication::allLyricistsProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allLyricistsProxyModel() const
 {
     return d->mAllLyricistsProxyModel.get();
 }
 
-AllTracksProxyModel *ElisaApplication::allTracksProxyModel() const
+QSortFilterProxyModel *ElisaApplication::allTracksProxyModel() const
 {
     return d->mAllTracksProxyModel.get();
 }
 
-SingleArtistProxyModel *ElisaApplication::singleArtistProxyModel() const
+QSortFilterProxyModel *ElisaApplication::singleArtistProxyModel() const
 {
     return d->mSingleArtistProxyModel.get();
 }
 
-SingleAlbumProxyModel *ElisaApplication::singleAlbumProxyModel() const
+QSortFilterProxyModel *ElisaApplication::singleAlbumProxyModel() const
 {
     return d->mSingleAlbumProxyModel.get();
 }
 
-FileBrowserProxyModel *ElisaApplication::fileBrowserProxyModel() const
+QSortFilterProxyModel *ElisaApplication::fileBrowserProxyModel() const
 {
+#if defined KF5KIO_FOUND && KF5KIO_FOUND
     return d->mFileBrowserProxyModel.get();
+#else
+    return nullptr;
+#endif
 }
 
 MediaPlayList *ElisaApplication::mediaPlayList() const
