@@ -87,7 +87,7 @@ int main(int argc, char *argv[])
 
     KAboutData aboutData( QStringLiteral("elisa"),
                           i18n("Elisa"),
-                          QStringLiteral("0.2.1"),
+                          QStringLiteral("0.2.80"),
                           i18n("A Simple Music Player written with KDE Frameworks"),
                           KAboutLicense::LGPL_V3,
                           i18n("(c) 2015-2018, Elisa contributors"));
@@ -130,7 +130,8 @@ int main(int argc, char *argv[])
 #if defined KF5Declarative_FOUND && KF5Declarative_FOUND
     KDeclarative::KDeclarative decl;
     decl.setDeclarativeEngine(&engine);
-    decl.setupBindings();
+    decl.setupEngine(&engine);
+    decl.setupContext();
 #endif
 
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
