@@ -63,6 +63,11 @@ class ELISALIB_EXPORT ManageHeaderBar : public QObject
                WRITE setImageRole
                NOTIFY imageRoleChanged)
 
+    Q_PROPERTY(int albumIdRole
+               READ albumIdRole
+               WRITE setAlbumIdRole
+               NOTIFY albumIdRoleChanged)
+
     Q_PROPERTY(int isValidRole
                READ isValidRole
                WRITE setIsValidRole
@@ -84,6 +89,10 @@ class ELISALIB_EXPORT ManageHeaderBar : public QObject
                READ image
                NOTIFY imageChanged)
 
+    Q_PROPERTY(qulonglong albumId
+               READ albumId
+               NOTIFY albumIdChanged)
+
     Q_PROPERTY(bool isValid
                READ isValid
                NOTIFY isValidChanged)
@@ -108,6 +117,8 @@ public:
 
     int imageRole() const;
 
+    int albumIdRole() const;
+
     int isValidRole() const;
 
     QVariant artist() const;
@@ -118,6 +129,8 @@ public:
 
     QUrl image() const;
 
+    qulonglong albumId() const;
+
     bool isValid() const;
 
     int remainingTracks() const;
@@ -136,6 +149,8 @@ Q_SIGNALS:
 
     void imageRoleChanged();
 
+    void albumIdRoleChanged();
+
     void isValidRoleChanged();
 
     void artistChanged();
@@ -148,6 +163,8 @@ Q_SIGNALS:
 
     void remainingTracksChanged();
 
+    void albumIdChanged();
+
     void isValidChanged();
 
 public Q_SLOTS:
@@ -164,6 +181,8 @@ public Q_SLOTS:
 
     void setImageRole(int value);
 
+    void setAlbumIdRole(int albumIdRole);
+
     void setIsValidRole(int isValidRole);
 
     void playListLayoutChanged(const QList<QPersistentModelIndex> &parents, QAbstractItemModel::LayoutChangeHint hint);
@@ -188,6 +207,8 @@ private:
 
     void notifyImageProperty();
 
+    void notifyAlbumIdProperty();
+
     void notifyIsValidProperty();
 
     void notifyRemainingTracksProperty();
@@ -204,6 +225,8 @@ private:
 
     int mImageRole = Qt::DisplayRole;
 
+    int mAlbumIdRole = Qt::DisplayRole;
+
     int mIsValidRole = Qt::DisplayRole;
 
     QVariant mOldArtist;
@@ -214,6 +237,8 @@ private:
 
     QVariant mOldImage;
 
+    qulonglong mOldAlbumId = 0;
+
     bool mOldIsValid = false;
 
     int mOldRemainingTracks = 0;
