@@ -124,29 +124,12 @@ QVariant AllAlbumsModel::data(const QModelIndex &index, int role) const
 
     const auto albumCount = d->mAllAlbums.size();
 
-    if (!index.isValid()) {
-        return result;
-    }
-
-    if (index.column() != 0) {
-        return result;
-    }
-
-    if (index.row() < 0) {
-        return result;
-    }
-
-    if (index.parent().isValid()) {
-        return result;
-    }
-
-    if (index.internalId() != 0) {
-        return result;
-    }
-
-    if (index.row() < 0 || index.row() >= albumCount) {
-        return result;
-    }
+    Q_ASSERT(index.isValid());
+    Q_ASSERT(index.column() == 0);
+    Q_ASSERT(index.row() >= 0 && index.row() < albumCount);
+    Q_ASSERT(!index.parent().isValid());
+    Q_ASSERT(index.model() == this);
+    Q_ASSERT(index.internalId() == 0);
 
     result = internalDataAlbum(index.row(), role);
     return result;
